@@ -4,7 +4,7 @@ from sqlalchemy import create_engine
 
 class pj_rf_sshdb():
     
-    def SSHDB(input_remote_server_IP, input_remote_server_port, input_ssh_username, 
+    def pj_rf_sshdb(input_remote_server_IP, input_remote_server_port, input_ssh_username, 
         input_ssh_password, input_remote_bind_address, input_remote_bind_address_port, input_db_server, input_db_name, input_query):
 
         with SSHTunnelForwarder(
